Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS Resource Explorer.

Actions, resources, and condition keys for AWS Resource Explorer - Service Authorization Reference

# Actions, resources, and condition keys for AWS Resource Explorer

AWS Resource Explorer (service prefix: `resource-explorer-2` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by AWS Resource Explorer
- Resource types defined by AWS Resource Explorer
- Condition keys for AWS Resource Explorer

## Actions defined by AWS Resource Explorer

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
AssociateDefaultView | Grants permission to set the specified view as the default for this AWS Region in this AWS account | Write | view* |  |
BatchGetView | Grants permission to retrieve details about views that you specify by a list of ARNs | Read |  |  | resource-explorer-2:GetView
CreateIndex | Grants permission to turn on Resource Explorer in the AWS Region in which you called this operation by creating an index | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
CreateView | Grants permission to create a view that users can query | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
DeleteIndex | Grants permission to turn off Resource Explorer in the specified AWS Region by deleting the index | Write | index* |  |
DeleteView | Grants permission to delete a view | Write | view* |  |
DisassociateDefaultView | Grants permission to remove the default view for the AWS Region in which you call this operation | Write |  |  |
GetDefaultView | Grants permission to retrieve the Amazon resource name (ARN) of the view that is the default for the AWS Region in which you call this operation | Read |  |  |
GetIndex | Grants permission to retrieve information about the index in the AWS Region in which you call this operation | Read |  |  |
GetView | Grants permission to retrieve information about the specified view | Read | view* |  |
ListIndexes | Grants permission to list the indexes in all AWS Regions | List |  |  |
ListSupportedResourceTypes | Grants permission to retrieve a list of all resource types currently supported by Resource Explorer | List |  |  |
ListTagsForResource | Grants permission to list the tags that are attached to the specified resource | Read | index |  |
view |  |
ListViews | Grants permission to list the Amazon resource names (ARNs) of all of the views available in the AWS Region in which you call this operation | List |  |  |
Search | Grants permission to search for resources and display details about all resources that match the specified criteria | Read | view* |  |
TagResource | Grants permission to add one or more tag key and value pairs to the specified resource | Tagging | index |  |
view |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UntagResource | Grants permission to remove one or more tag key and value pairs from the specified resource | Tagging | index |  |
view |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UpdateIndexType | Grants permission to change the type of the index from LOCAL to AGGREGATOR or back | Write | index* |  |
UpdateView | Grants permission to modify some of the details of a view | Write | view* |  |

## Resource types defined by AWS Resource Explorer

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the Resource types table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
view | `arn:$ { Partition}:resource-explorer-2:$ { Region}:$ { Account}:view/$ { ViewName}/$ { ViewUuid}` | aws:ResourceTag/${TagKey}
index | `arn:$ { Partition}:resource-explorer-2:$ { Region}:$ { Account}:index/$ { IndexUuid}` | aws:ResourceTag/${TagKey}

## Condition keys for AWS Resource Explorer

AWS Resource Explorer defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by the tag keys that are passed in the request | String
aws:ResourceTag/${TagKey} | Filters access by the tag keyss attached to the resource | String
aws:TagKeys | Filters access by the tag keys that are passed in the request | ArrayOfString

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.